@@ -2,15 +2,16 @@ from pyopereto.client import OperetoClient
 from threading import Timer
 
 class ProcessLogScheduler():
-    """
-        from time import sleep
-        p = ProcessLogScheduler(1)
-        p.write('eAsEFPGfJun', [{'text': 'my log entry 1', 'level': 'INFO'}])
-        p.write('eAsEFPGfJun', [{'text': 'my log entry 2', 'level': 'INFO'}])
-        p.write('53cqHRdu4Cr', [{'text': 'some log text..', 'level': 'ERROR'}])
-        sleep(5)  # your long-running job goes here...
 
     """
+        from time import sleep
+        with ProcessLogScheduler(1) as p:
+            p.write('eAsEFPGfJun', [{'text': 'my log entry 1', 'level': 'INFO'}])
+            p.write('eAsEFPGfJun', [{'text': 'my log entry 2', 'level': 'INFO'}])
+            p.write('53cqHRdu4Cr', [{'text': 'some log text..', 'level': 'ERROR'}])
+            sleep(5)  # your long-running job goes here...
+    """
+
     def __init__(self, interval=5):
         self.buffer = {
             0: {},
@@ -23,6 +24,12 @@ class ProcessLogScheduler():
         self.interval = interval
         self.start()
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        self.flush_logs()
+
     def _switch_buffer(self):
         active_buffer_sn = self.active_buffer
         self.active_buffer = abs(int(self.active_buffer) - 1)
@@ -30,9 +37,6 @@ class ProcessLogScheduler():
         self.buffer[active_buffer_sn]={}
         return logs
 
-    def __del__(self):
-        self.stop()
-
     def flush_logs(self, *args):
         self.is_running = False
         self.start()
